@@ -186,7 +186,9 @@ class CRFExtractor:
                 facts.append(tag)
 
         out_doc = {
-            "text": tokenized_text,
+            field_name: {
+                FEATURE_LAYER_WORD: tokenized_text
+            },
             "texta_facts": facts
         }
         return out_doc
@@ -239,7 +241,7 @@ class CRFExtractor:
                 "fact": fact_name,
                 "str_val": str_val,
                 "sent_index": sent_index,
-                "doc_path": field_name,
+                "doc_path": f"{field_name}.{FEATURE_LAYER_WORD}",
                 "spans": json.dumps(matching_spans)
             }
             yield fact
